@@ -2,16 +2,20 @@
 #' codes.
 #' 
 #' @import httr plyr assertthat
-#' @importFrom RJSONIO fromJSON
 #' @export
-#' @template all
+#' 
 #' @param type Type of data, one of catalog_number, collection_code, collector_name, 
 #' institution_code. Unique partial strings work too, like 'cat' for catalog_number
 #' @param q Search term
 #' @param limit Number of results, default=5
-#' @param callopts Args passed on to \code{httr::GET}
 #' @param pretty Pretty as true (Default) uses cat to print data, FALSE gives 
 #' character strings.
+#' @param ... Further named parameters, such as \code{query}, \code{path}, etc, passed on to 
+#' \code{\link[httr]{modify_url}} within \code{\link[httr]{GET}} call. Unnamed parameters will be 
+#' combined with \code{\link[httr]{config}}.
+#' 
+#' @references \url{http://www.gbif.org/developer/occurrence#search}
+#' 
 #' @examples \dontrun{
 #' # catalog number
 #' occ_metadata(type = "catalogNumber", q=122)
@@ -30,6 +34,11 @@
 #' 
 #' # Partial unique type strings work too
 #' occ_metadata(type = "cat", q=122)
+#' 
+#' # Pass on options to httr
+#' library('httr')
+#' occ_metadata(type = "cat", q=122, config=verbose())
+#' occ_metadata(type = "cat", q=122, config=progress())
 #' }
 #' 
 #' @examples \donttest{
@@ -37,21 +46,15 @@
 #' occ_metadata(type = "collector_name", q='jane')
 #' }
 
-occ_metadata <- function(type = "catalogNumber", q=NULL, limit=5, 
-                         callopts=list(), pretty=TRUE)
+occ_metadata <- function(type = "catalogNumber", q=NULL, limit=5, pretty=TRUE, ...)
 {
-  type <- match.arg(type, choices=c("catalogNumber","collectionCode",
-                                    "collectorName","institutionCode"))
-  url <- sprintf('http://api.gbif.org/v1/occurrence/search/%s', type)
+  type <- match.arg(type, c("catalogNumber","collectionCode","collectorName","institutionCode"))
+  url <- sprintf('%s/occurrence/search/%s', gbif_base(), type)
   args <- rgbif_compact(list(q = q, limit = limit))
-  tt <- GET(url, query=args, callopts)
-  stop_for_status(tt)
-  assert_that(tt$headers$`content-type`=='application/json')
-  res <- content(tt, as = 'text', encoding = "UTF-8")
-  out <- RJSONIO::fromJSON(res, simplifyWithNames = FALSE)
+  out <- gbif_GET(url, args, TRUE, ...)
   
-  if(pretty){
+  if(pretty)
     cat(out, sep="\n")
-  } else
-  { out }
-}
\ No newline at end of file
+  else
+    out
+}
