@@ -17,7 +17,7 @@ test_that("keyword query returns the correct class", {
 })
 test_that("keyword query returns the correct value", {
   expect_equal(as.character(tt$data$publishingCountry[1]), "FR")
-  expect_equal(as.character(tt$data[1,4]), "FR")
+  expect_equal(as.character(tt$data[1,4]), "Tela Botanica")
 })
  
 # Fulltext search for all datasets having the word "amsterdam" somewhere in 
@@ -39,11 +39,11 @@ test_that("limited search returns the correct class", {
   expect_is(tt$data[1,1], "character")
 })
 test_that("limited search returns the correct dims", {
-  expect_equal(dim(tt$data), c(2,6))
+  expect_equal(dim(tt$data), c(2,8))
 })
  
 # Return just descriptions
 tt <- dataset_search(type="OCCURRENCE", return="descriptions")
 test_that("limited fields query returns the correct class", {
   expect_is(tt, "list")
-})
\ No newline at end of file
+})
