@@ -22,13 +22,13 @@ test_that("returns the correct value", {
   expect_equal(as.character(uu$hierarchy[[1]][1,1]), "Plantae")
   expect_equal(as.character(uu$data[1,1]), "Helianthus annuus")
   expect_equal(uu$meta$limit, 20)
-  expect_equal(vv$limit, 20)
+  expect_equal(vv$limit, 200)
 })
 
 test_that("returns the correct dimensions", {
   expect_equal(length(tt), 4)
   expect_equal(length(tt$meta), 4)
-  expect_equal(length(uu$data), 4)
+  expect_equal(length(uu$data), 71)
   expect_equal(ncol(vv), 4)
 })
 
@@ -39,7 +39,7 @@ test_that("returns the correct class", {
   expect_is(out, "data.frame")
 })
 test_that("returns the correct dimensions", {
-  expect_equal(dim(out), c(20,4))
+  expect_equal(dim(out), c(177,42))
 })
 
 ## Search by catalog number
@@ -63,7 +63,7 @@ out <- occ_search(taxonKey=key, return='data')
 test_that("returns the correct class", {
   expect_is(out, "data.frame")
   expect_is(out[1,1], "character")
-  expect_is(out[1,2], "numeric")
+  expect_is(out[1,2], "integer")
 })
 test_that("returns the correct value", {
   expect_equal(as.character(out[1,1]), "Helianthus annuus")
@@ -116,4 +116,4 @@ test_that("returns the correct dimensions", {
   key <- name_backbone(name='Puma concolor', kingdom='animals')$speciesKey
   res <- occ_search(taxonKey=key, elevation=1000, hasCoordinate=TRUE, fields=c('name','elevation'))
   expect_equal(names(res$data), c('name','elevation'))
-})
\ No newline at end of file
+})
